# cowfish

[![Build Status](https://travis-ci.org/guyingbo/cowfish.svg?branch=master)](https://travis-ci.org/guyingbo/cowfish)

A useful asynchronous library bases on aiobotocore

## usage

~~~
python -m cowfish.sqsprocesser queue_name region_name
~~~
